.. Pyimfit documentation master file, created by
   sphinx-quickstart on Mon Jan 28 14:24:16 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Documentation for PyImfit
===================================


.. toctree::
   :maxdepth: 3
   :caption: OVERVIEW AND SAMPLE USAGE:

   installation
   sample_usage
   overview

.. toctree::
   :maxdepth: 2
   :caption: USER DOCUMENTATION:

   defining_models
   psf_convolution
   fit_statistics_and_solvers
   bootstrap
   pyimfit_emcee
   pyimfit_bootstrap_BtoT
   acknowledgments


.. toctree::
   :maxdepth: 2
   :caption: API DOCUMENTATION:

   api_ref/api_index


`Imfit manual (PDF) <https://www.mpe.mpg.de/~erwin/resources/imfit/imfit_howto.pdf>`_

